@@ -8,6 +8,9 @@ echo "#"
 # Add the test names that are known to fail or flaky
 PERMISSIVE_LIST=(
 inline_container_test
+pow_test
+native_test
+op_registration_test
 )
 
 for (( i = 0; i < ${#FILES[@]}; i++ )); do
